==> pmml-model-gwt-1.3.7-sources.jar: org/dmg/pmml/general_regression/PCovCell.java <==

package org.dmg.pmml.general_regression;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="pRow" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="pCol" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="tRow" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="tCol" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       &lt;attribute name="value" use="required" type="{http://www.dmg.org/PMML-4_3}REAL-NUMBER" />
 *       &lt;attribute name="targetCategory" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "PCovCell", namespace = "http://www.dmg.org/PMML-4_3")
public class PCovCell
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<PCovCell>
{

    @XmlAttribute(name = "pRow", required = true)
    private String pRow;
    @XmlAttribute(name = "pCol", required = true)
    private String pCol;
    @XmlAttribute(name = "tRow")
    private String tRow;
    @XmlAttribute(name = "tCol")
    private String tCol;
    @XmlAttribute(name = "value", required = true)
    private double value;
    @XmlAttribute(name = "targetCategory")
    private String targetCategory;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67305475L;

    public PCovCell() {
    }

    public PCovCell(
        @org.jpmml.model.Property("pRow")
        String pRow,
        @org.jpmml.model.Property("pCol")
        String pCol,
        @org.jpmml.model.Property("value")
        double value) {
        this.pRow = pRow;
        this.pCol = pCol;
        this.value = value;
    }

    /**
     * Gets the value of the pRow property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRow() {
        return pRow;
    }

    /**
     * Sets the value of the pRow property.
     * 
     * @param pRow
     *     allowed object is
     *     {@link String }
     *     
     */
    public PCovCell setPRow(
        @org.jpmml.model.Property("pRow")
        String pRow) {
        this.pRow = pRow;
        return this;
    }

    /**
     * Gets the value of the pCol property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPCol() {
        return pCol;
    }

    /**
     * Sets the value of the pCol property.
     * 
     * @param pCol
     *     allowed object is
     *     {@link String }
     *     
     */
    public PCovCell setPCol(
        @org.jpmml.model.Property("pCol")
        String pCol) {
        this.pCol = pCol;
        return this;
    }

    /**
     * Gets the value of the tRow property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRow() {
        return tRow;
    }

    /**
     * Sets the value of the tRow property.
     * 
     * @param tRow
     *     allowed object is
     *     {@link String }
     *     
     */
    public PCovCell setTRow(
        @org.jpmml.model.Property("tRow")
        String tRow) {
        this.tRow = tRow;
        return this;
    }

    /**
     * Gets the value of the tCol property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTCol() {
        return tCol;
    }

    /**
     * Sets the value of the tCol property.
     * 
     * @param tCol
     *     allowed object is
     *     {@link String }
     *     
     */
    public PCovCell setTCol(
        @org.jpmml.model.Property("tCol")
        String tCol) {
        this.tCol = tCol;
        return this;
    }

    /**
     * Gets the value of the value property.
     * 
     */
    public double getValue() {
        return value;
    }

    /**
     * Sets the value of the value property.
     * 
     */
    public PCovCell setValue(
        @org.jpmml.model.Property("value")
        double value) {
        this.value = value;
        return this;
    }

    /**
     * Gets the value of the targetCategory property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTargetCategory() {
        return targetCategory;
    }

    /**
     * Sets the value of the targetCategory property.
     * 
     * @param targetCategory
     *     allowed object is
     *     {@link String }
     *     
     */
    public PCovCell setTargetCategory(
        @org.jpmml.model.Property("targetCategory")
        String targetCategory) {
        this.targetCategory = targetCategory;
        return this;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    public PCovCell addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.4.9-sources.jar: org/dmg/pmml/general_regression/PCovCell.java <==

package org.dmg.pmml.general_regression;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "PCovCell", namespace = "http://www.dmg.org/PMML-4_3")
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "pRow",
    "pCol",
    "tRow",
    "tCol",
    "value",
    "targetCategory",
    "extensions"
})
public class PCovCell
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<PCovCell>
{

    @XmlAttribute(name = "pRow", required = true)
    @JsonProperty("pRow")
    private String pRow;
    @XmlAttribute(name = "pCol", required = true)
    @JsonProperty("pCol")
    private String pCol;
    @XmlAttribute(name = "tRow")
    @JsonProperty("tRow")
    private String tRow;
    @XmlAttribute(name = "tCol")
    @JsonProperty("tCol")
    private String tCol;
    @XmlAttribute(name = "value", required = true)
    @JsonProperty("value")
    private double value;
    @XmlAttribute(name = "targetCategory")
    @JsonProperty("targetCategory")
    private String targetCategory;
    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    private final static long serialVersionUID = 67305486L;

    public PCovCell() {
    }

    public PCovCell(
        @org.jpmml.model.annotations.Property("pRow")
        String pRow,
        @org.jpmml.model.annotations.Property("pCol")
        String pCol,
        @org.jpmml.model.annotations.Property("value")
        double value) {
        this.pRow = pRow;
        this.pCol = pCol;
        this.value = value;
    }

    public String getPRow() {
        return pRow;
    }

    public PCovCell setPRow(
        @org.jpmml.model.annotations.Property("pRow")
        String pRow) {
        this.pRow = pRow;
        return this;
    }

    public String getPCol() {
        return pCol;
    }

    public PCovCell setPCol(
        @org.jpmml.model.annotations.Property("pCol")
        String pCol) {
        this.pCol = pCol;
        return this;
    }

    public String getTRow() {
        return tRow;
    }

    public PCovCell setTRow(
        @org.jpmml.model.annotations.Property("tRow")
        String tRow) {
        this.tRow = tRow;
        return this;
    }

    public String getTCol() {
        return tCol;
    }

    public PCovCell setTCol(
        @org.jpmml.model.annotations.Property("tCol")
        String tCol) {
        this.tCol = tCol;
        return this;
    }

    public double getValue() {
        return value;
    }

    public PCovCell setValue(
        @org.jpmml.model.annotations.Property("value")
        double value) {
        this.value = value;
        return this;
    }

    public String getTargetCategory() {
        return targetCategory;
    }

    public PCovCell setTargetCategory(
        @org.jpmml.model.annotations.Property("targetCategory")
        String targetCategory) {
        this.targetCategory = targetCategory;
        return this;
    }

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public PCovCell addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
